@@ -5,7 +5,7 @@
 ;; Author: Yuan Fu <casouri@gmail.com>
 ;; Maintainer: Yuan Fu <casouri@gmail.com>
 ;; URL: https://github.com/casouri/expreg
-;; Version: 1.0.0
+;; Version: 1.1.0
 ;; Keywords: text, editing
 ;; Package-Requires: ((emacs "29.1"))
 ;;
@@ -38,6 +38,10 @@
 ;;     (region A)|(region B)
 ;;
 ;; Expreg also recognizes subwords if ‘subword-mode’ is on.
+;;
+;; By default, the sentence expander ‘expreg--sentence’ is not
+;; enabled. I suggest enabling it (by adding it to ‘expreg-functions’)
+;; in text modes only.
 
 ;;; TODO
 ;;
@@ -79,8 +83,8 @@
 (require 'subword)
 (require 'treesit)
 (eval-when-compile
-  (require 'cl-lib)
-  (require 'seq))
+  (require 'cl-lib))
+(require 'seq)
 
 ;;; Cutom options and variables
 
@@ -209,12 +213,13 @@ This should be a list of (BEG . END).")
   "The regions we’ve expanded past.
 This should be a list of (BEG . END).")
 
+;;;###autoload
 (defun expreg-expand ()
   "Expand region."
   (interactive)
   ;; Checking for last-command isn’t strictly necessary, but nice to
   ;; have.
-  (when (not (and (region-active-p)
+  (when (not (and (use-region-p)
                   (eq (region-beginning)
                       (cadr (car expreg--prev-regions)))
                   (eq (region-end)
@@ -236,7 +241,7 @@ This should be a list of (BEG . END).")
 
   ;; Go past all the regions that are smaller than the current region,
   ;; if region is active.
-  (when (region-active-p)
+  (when (use-region-p)
     (while (and expreg--next-regions
                 (let ((beg (cadr (car expreg--next-regions)))
                       (end (cddr (car expreg--next-regions))))
@@ -251,18 +256,21 @@ This should be a list of (BEG . END).")
     (let ((region (pop expreg--next-regions)))
       (set-mark (cddr region))
       (goto-char (cadr region))
-      (push region expreg--prev-regions)))
+      (push region expreg--prev-regions)
+      (unless transient-mark-mode
+        (activate-mark))))
 
   (when expreg--verbose
     (message "blame: %s\nnext: %S\nprev: %S"
              (caar expreg--prev-regions)
              expreg--next-regions expreg--prev-regions)))
 
+;;;###autoload
 (defun expreg-contract ()
   "Contract region."
   (interactive)
-  (when (and (region-active-p)
-             (> (length expreg--prev-regions) 1))
+  (when (and (use-region-p)
+             (length> expreg--prev-regions 1))
 
     (push (pop expreg--prev-regions) expreg--next-regions)
     (set-mark (cddr (car expreg--prev-regions)))
@@ -593,6 +601,16 @@ current string/comment and get lists inside."
       (push `(comment . ,(cons beg end)) result))
     result))
 
+(defun expreg--sentence ()
+  "Return a list of regions containing surrounding sentences."
+  (ignore-errors
+    (let (beg end)
+      (forward-sentence)
+      (setq end (point))
+      (backward-sentence)
+      (setq beg (point))
+      `((sentence . ,(cons beg end))))))
+
 (defun expreg--paragraph ()
   "Return a list of regions containing paragraphs or defuns."
   (condition-case nil
